#!/bin/bash

########### Make Directories ###################################################

mkdir -p model output align

########### Language Model Training ############################################

# Train the language model
script/train-bigram.py data/kyoto-tunesmall.en > model/bigram.txt

########### Alignment ##########################################################

# 1) Calculate the dice coefficient using the small corpus
script/train-dice.py data/kyoto-tunesmall.ja data/kyoto-tunesmall.en > model/dice-tunesmall.ja-en

# 2) Create a score file in reverse order
script/reverse-score.py model/dice-tunesmall.ja-en > model/dice-tunesmall.en-ja

# 3) Use the max-score rule to calculate these in ja-en and en-ja order
script/max-score.py data/kyoto-tune.ja data/kyoto-tune.en model/dice-tunesmall.ja-en > align/kyoto-tunesmall.ja-en
script/max-score.py data/kyoto-tune.en data/kyoto-tune.ja model/dice-tunesmall.en-ja > align/kyoto-tunesmall.en-ja

# 4) Use the "intersection" heuristic to calculate the actual alignments
script/intersect.py align/kyoto-tunesmall.ja-en align/kyoto-tunesmall.en-ja > align/kyoto-tunesmall.intersect.ja-en

########### Phrase Training ####################################################

# Do phrase extraction
script/phrase-extract.py data/kyoto-tunesmall.{ja,en} align/kyoto-tunesmall.intersect.ja-en > model/phrase-table.txt

########### Translation ########################################################

# Do translation
script/decoder.py model/phrase-table.txt model/bigram.txt < data/kyoto-dev-upto20.ja | tee output/kyoto-dev-upto20.en

# Do evaluation
script/bleu.py output/kyoto-dev-upto20.en data/kyoto-dev-upto20.en
